==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/server/inc/quarantine/item.php <==
<?php

define('CRLF',"\r\n");

require_once ('inc/api/api.php');
require_once ('inc/folder.php');

class QuarantineItem extends Item
{
  //Param - record from spam.db, exploded by ";"
  public function __construct($folder,$param,$single = false)
  {

    $this->sender = $param[0];
    $this->createdOn = $param[1];
    $this->createdAt = $param[5];
    $this->domain = $param[6];
    $this->subject = $param[7];
    $this->owner = $param[4];
    $this->wmclass = 'Q';   
    $this->quarantineFolder = $param[2];
    $this->itemID = $param[0].'#'.$param[4];
    //if ($single)
    $this->folder = $folder;  
  }
  
  public static function create($folder,$param)
  {
    return self::doAction($param['email'],$_SESSION['EMAIL'],$folder->iAuthorized);
  }
  
  public function delete($cache = array())
  {
    if (!$cache['api']) $cache['api'] = new MerakAPI;
    return $cache['api']->QuarantineDelete($this->owner,$this->sender,$this->quarantineFolder);   
  }

  public function whitelist($cache = array(),$deliver = false)
  {
    if ($deliver){
      if (!$cache['api']) $cache['api'] = new MerakAPI;
      $cache['api']->QuarantineAuthorize($this->quarantineFolder);
    }
    return self::doAction($this->sender,$this->owner,(int) 1,$cache);   
  }
  
  public function blacklist($cache = array())
  {
    return self::doAction($this->sender,$this->owner,(int) 0,$cache); 
  } 
   
  public function deliver($cache = array())
  {
    if (!$cache['api']) $cache['api'] = new MerakAPI;
    $cache['api']->QuarantineAuthorize($this->quarantineFolder);
    $cache['api']->QuarantineDelete($this->owner,$this->sender,$this->quarantineFolder);
    return true;
  }  
  
  //Abstract required methods (therefore they have to be defined)
  public function edit()
  {}
    
  public function move($folder)
  {}
  
  public function getMessage()
  {
    $path = $_SESSION['USERDIR'].'~spam/~quarantine/'.$this->quarantineFolder.'/';
    $items = glob($path.'*.tmp');
    return file_get_contents($items[0]);
  }
	/**
	  @brief Get the structure of message of the item.
	  @return Message structure.
	 */
	public function parseMessage()
	{
		$message = $this->getMessage();
			
		//parse message
		$parser = &new MailParse($message, array(), true);
		
    $structure = $parser->parse();
		$structure['headers_plain'] = substr($message,0,strpos($message,CRLF.CRLF));
		
		return $structure;
	} 
	
	private static function doAction($sender,$owner,$param,$cache = array())
	{
    if (!$cache['api']) $cache['api'] = new MerakAPI();

    //Create item  - update existing or create new record in challenge.mdb
    $list = $cache['api']->QuarantineList(''," WHERE SndOwner = '".$owner."' AND SndEmail='".$sender."'",
                                0);
                   
    if (!$list)
       $result = $cache['api']->QuarantineAdd($owner,$sender,$param);
    else
       $result = $cache['api']->QuarantineSet($owner,$sender,$param);
    
    return $result;    
  }

}
?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/server/inc/quarantine/item.php <==
<?php
require_once ('inc/api/api.php');
require_once ('inc/folder.php');

class QuarantineItem extends Item
{
  //Param - record from spam.db, exploded by ";"
  public function __construct($folder,$param,$single = false)
  {

    $this->sender = $param[0];
    $this->createdOn = $param[1];
    $this->createdAt = $param[5];
    $this->domain = $param[6];
    $this->subject = $param[7];
    $this->owner = $param[4];
    $this->wmclass = 'Q';   
    $this->quarantineFolder = $param[2];
    $this->itemID = $param[0].'#'.$param[4];
    //if ($single)
    $this->folder = $folder;  
  }
  
  public static function create($folder,$param)
  {
    return self::doAction($param['email'],$_SESSION['EMAIL'],$folder->iAuthorized);
  }
  
  public function delete($cache = array())
  {
    if (!$cache['api']) $cache['api'] = new MerakAPI;
    return $cache['api']->QuarantineDelete($this->owner,$this->sender,$this->quarantineFolder);   
  }

  public function whitelist($cache = array(),$deliver = false)
  {
    if ($deliver){
      if (!$cache['api']) $cache['api'] = new MerakAPI;
      $cache['api']->QuarantineAuthorize($this->quarantineFolder);
    }
    return self::doAction($this->sender,$this->owner,(int) 1,$cache);   
  }
  
  public function blacklist($cache = array())
  {
    return self::doAction($this->sender,$this->owner,(int) 0,$cache); 
  } 
   
  public function deliver($cache = array())
  {
    if (!$cache['api']) $cache['api'] = new MerakAPI;
    $cache['api']->QuarantineAuthorize($this->quarantineFolder);
    $cache['api']->QuarantineDelete($this->owner,$this->sender,$this->quarantineFolder);
    return true;
  }  
  
  //Abstract required methods (therefore they have to be defined)
  public function edit()
  {}
    
  public function move($folder)
  {}
  
  public function getMessage()
  {
    $path = $_SESSION['USERDIR'].'~spam/~quarantine/'.$this->quarantineFolder.'/';
    $items = glob($path.'*.tmp');
    return @file_get_contents($items[0]);
  }
  public function getMessageFile()
  {
    $path = $_SESSION['USERDIR'].'~spam/~quarantine/'.$this->quarantineFolder.'/';
    $items = glob($path.'*.tmp');
    return $items[0];
  }
	/**
	  @brief Get the structure of message of the item.
	  @return Message structure.
	 */
	public function parseMessage()
	{
		$file = $this->getMessageFile();
			
		//parse message
		$parser = &new MailParse($file, array(), true);
		
    $structure = $parser->parse();
		$structure['headers_plain'] = substr($message,0,strpos($message,CRLF.CRLF));
		
		return $structure;
	} 
	
	private static function doAction($sender,$owner,$param,$cache = array())
	{
    if (!$cache['api']) $cache['api'] = new MerakAPI();

    //Create item  - update existing or create new record in challenge.mdb
    $list = $cache['api']->QuarantineList(''," WHERE SndOwner = '".$owner."' AND SndEmail='".$sender."'",
                                0);
    $filter="||SndOwner=".urlencode($owner)."&SndEmail=".urlencode($sender);
    $list = $cache['api']->QuarantineList('',$filter,0);  

                   
    if (!$list)
       $result = $cache['api']->QuarantineAdd($owner,$sender,$param);
    else
       $result = $cache['api']->QuarantineSet($owner,$sender,$param);
    
    return $result;    
  }

}
?>
